@@ -22,7 +22,7 @@ Usage::
     search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
     ```
 """
-from typing import Generic, Iterator, List, TypeVar
+from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -52,7 +52,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListGroupResourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupresourcespaginator)
     """
 
@@ -61,36 +61,36 @@ class ListGroupResourcesPaginator(Boto3Paginator):
         *,
         GroupName: str = None,
         Group: str = None,
-        Filters: List["ResourceFilterTypeDef"] = None,
+        Filters: Sequence["ResourceFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListGroupResourcesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupresourcespaginator)
         """
 
 
 class ListGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupspaginator)
     """
 
     def paginate(
         self,
         *,
-        Filters: List["GroupFilterTypeDef"] = None,
+        Filters: Sequence["GroupFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupspaginator)
         """
 
 
 class SearchResourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#searchresourcespaginator)
     """
 
@@ -101,6 +101,6 @@ class SearchResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[SearchResourcesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#searchresourcespaginator)
         """
